package nstautil

import (
	"bytes"
	"sync"
)

// SyncBuffer implements locked access to bytes.Buffer for multithreaded access
// this is only for small amounts of data useful and not high-io
type SyncBuffer struct {
	mtx sync.Mutex

	buf bytes.Buffer
}

func (b *SyncBuffer) Len() int {
	b.mtx.Lock()
	defer b.mtx.Unlock()

	return b.buf.Len()
}

func (b *SyncBuffer) String() string {
	b.mtx.Lock()
	defer b.mtx.Unlock()

	return b.buf.String()
}

func (b *SyncBuffer) Write(p []byte) (n int, err error) {
	b.mtx.Lock()
	defer b.mtx.Unlock()

	return b.buf.Write(p)
}

func (b *SyncBuffer) Reset() {
	b.mtx.Lock()
	defer b.mtx.Unlock()

	b.buf = bytes.Buffer{}
}
